@@ -29,7 +29,7 @@ class Dataset:
                 'name': self.name,
                 'shape': self.shape
             },
-            verify=os.getenv('MASO_CERT_CHAIN')
+            verify=False
         )
 
         response.raise_for_status()
@@ -43,7 +43,7 @@ class Dataset:
         response = requests.get(
             f'{Config.base_url}/dataset/{self.id}',
             headers={"Authorization": f"{self.api_token}"},
-            verify=os.getenv('MASO_CERT_CHAIN'),
+            verify=False,
         )
 
         response.raise_for_status()
@@ -62,7 +62,7 @@ class Dataset:
                 'data': list(data.flatten('F')),
                 'slice': slc
             },
-            verify=os.getenv('MASO_CERT_CHAIN')
+            verify=False
         )
 
         response.raise_for_status()
@@ -74,7 +74,7 @@ class Dataset:
             params={
                 'slice': tuple(slc)
             },
-            verify=os.getenv('MASO_CERT_CHAIN')
+            verify=False
         )
 
         response.raise_for_status()
@@ -94,7 +94,7 @@ class Dataset:
             params={
                 'key': key
             },
-            verify=os.getenv('MASO_CERT_CHAIN')
+            verify=False
         )
 
         response.raise_for_status()
